require 'thor'
require 'slog'

require_relative 'alias'
require_relative 'reindex'
require_relative 'helpers'
require_relative 'metadata'


module Esteem

  # Esteem's entrypoint.
  class Main < Thor
    include Esteem::Helpers


    desc 'version', 'Echo the application version'
    def version
      puts VERSION
      return nil
    end


    desc 'art', 'View the application art'
    def art
      puts
      puts ART
      puts
      return nil
    end


    desc 'reindex', 'Move data to a new index gracefully'
    option :update, type: :boolean, aliases: %w[ -u ], default: false
    option :frame, type: :numeric, aliases: %w[ -f ], default: 1000
    option :source, type: :string, aliases: %w[ -s ], required: true
    option :destination, type: :string, aliases: %w[ -d ], required: true
    def reindex
      reindex = Reindex.new \
        update: options.update?,
        frame: options.frame,
        src: options.source,
        dst: options.destination
      return reindex.success
    end

    desc 'alias', 'Add daily aliases for the given month'
    option :month, type: :numeric, aliases: %w[ -m ], required: true
    option :year, type: :numeric, aliases: %w[ -y ], default: Time.now.year
    option :host, type: :string, aliases: %w[ -h ], default: 'http://localhost:9200'
    def alias
      aliasing = Alias.new \
        month: options.month,
        year: options.year,
        host: options.host
      return aliasing.success
    end

  end
end